﻿Type=Class
Version=3
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
#Region Copyright
' This file is part of the B4J Project Library jRLMsgDialogsNonUIClass
'                                                                              
' This Source Code is subject to the terms of the Mozilla Public License,
' v. 2.0. If a copy of the MPL was Not distributed with this File, You can
' obtain one at http://mozilla.org/MPL/2.0/
' 
' Copyright (C) 2014, Robert W.B. Linn, Pinneberg, Germany (www.rwblinn.de).
' Internet: www.rwblinn.de, E-Mail: robert@rwblinn.de
' Read readme.txt for any latest information                                       
'
#End Region

#Region Notes
' This library makes for most of the dialogs use of the Java Swing Library
' Read more here:    
' http://docs.oracle.com/javase/7/docs/api/javax/swing/JOptionPane.html
' http://docs.oracle.com/javase/tutorial/uiswing/components/dialog.html
'
' Version 20140506
' TODO: None
'
#End Region

#Region Examples
' Various examples calling defined methods
' 
' A global must be declared and initialized
' Sub Process_Globals
' Declare the global messagedialog
' ...
' Dim gDlg As jRLMsgDialogs
' ...
' Sub AppStart...
' ..
' Init the global messagedialog
' gDlg.Initialize
'
' Usage:
' gDlg.showMessage("<html><h1>Moin Moin</h1><hr><p>Greeting from Hamburg (Germany)</p>")	
' gDlg.showMessage2("<html>Moin Moin<hr><p>Greeting from Hamburg (Germany)</p>", "Title", gDlg.MSGTYPE_QUESTION)
' gDlg.showConfirmDialog("Please Confirm!")
' gDlg.showOptionDialog("Message", "Title", gDlg.OPTION_DEFAULT, gDlg.MSGTYPE_INFORMATION, l)
' gDlg.showInputDialog("Message")	
' gDlg.showInputDialog2("Message", "Title")
' gDlg.showInputDialog3("Message", "Title", 2)
' gDlg.showInputDialog4("Message", "Title", 2, Array As Object("A","B","C"))
' Dim l As List
' l.Initialize
' l.AddAll(Array As String("A","B","C"))
' jRLMsgDialogs.showInputDialog4("Message", "Title", 2, l)
' Dim s As String
' For i = 0 To 50
'	 s = s & "<p>" & "Line " & i & "</p>" 
' Next
' jRLMsgDialogs.showAbout(CMSGABOUT)	
#End Region

Private Sub Class_Globals
	' Specifies the set of buttons that appear at the bottom of the dialog. 
	Public OPTION_DEFAULT As Int = 0
	Public OPTION_YES_NO As Int = 1
	Public OPTION_YES_NO_CANCEL As Int = 2
	Public OPTION_OK_CANCEL As Int = 3
	
	' Determines the icon displayed in the dialog. 
	Public MSGTYPE_PLAIN As Int = -1
	Public MSGTYPE_ERROR As Int = 0
	Public MSGTYPE_INFORMATION As Int = 1
	Public MSGTYPE_WARNING As Int = 2
	Public MSGTYPE_QUESTION As Int = 3
End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize

End Sub

' Show Messagedialog
' Parameter Message as String
Public Sub showMessage(strMsg As String)
	' Define the javaobject
	Dim jo As JavaObject
	' Initialize using the Swing Library class JOptionPane
	jo.InitializeStatic("javax.swing.JOptionPane")
	' Show the message
	jo.RunMethod("showMessageDialog", Array As Object(Null, strMsg))
End Sub

' Show Messagedialog
' Parameter Message as String
' Parameter Heading as String
' Parameter Messagetype as Int
Public Sub showMessage2(strMsg As String, strHdg As String, nMsgType As Int)
	' Define the javaobject
	Dim jo As JavaObject
	' Initialize using the Swing Library class JOptionPane
	jo.InitializeStatic("javax.swing.JOptionPane")
	' Show the message
	jo.RunMethod("showMessageDialog", Array As Object(Null, strMsg, strHdg, nMsgType))
End Sub

' Show confirmation dialog
' Parameter Message as String
' Returns 0 = Yes, 1 = No, 2 = Cancel
Public Sub showConfirmDialog(strMsg As String) As String
	' Define the javaobject
	Dim jo As JavaObject
	' Initialize using the Swing Library class JOptionPane
	jo.InitializeStatic("javax.swing.JOptionPane")
	Dim nRT As Int = jo.RunMethod("showConfirmDialog", Array As Object(Null, strMsg))
	Return nRT
	'Log("showConfirmDialog: " & nRT)
End Sub

' Returns Option selected as a string
Public Sub showOptionDialog(strMsg As String, strTitle As String, optionType As Int, msgType As Int, lstOptions As List) As Int
	' Convert the list into an array of objects
	Dim objOptions(lstOptions.Size) As Object
	For i = 0 To lstOptions.Size - 1
 		objOptions(i) = lstOptions.Get(i)
	Next	
	' Define the javaobject
	Dim jo As JavaObject
	' Initialize using the Swing Library class JOptionPane
	jo.InitializeStatic("javax.swing.JOptionPane")
	Dim nRT As Int = jo.RunMethod("showOptionDialog", Array As Object(Null, strMsg, strTitle, optionType, msgType, Null, objOptions, Null))
	Return nRT
	' Log("showOptionDialog: " & nRT)
End Sub

Public Sub showInputDialog(strMsg As String) As String
	' Define the javaobject
	Dim jo As JavaObject
	' Initialize using the Swing Library class JOptionPane
	jo.InitializeStatic("javax.swing.JOptionPane")
	' Returns Input as text
	Dim strInput As String = jo.RunMethod("showInputDialog", Array As Object(strMsg))
	If strInput = "null" Then strInput = ""
	Return strInput
	' Log("showInputDialog: " & strInput)
End Sub

' Returns Input as text
Public Sub showInputDialog2(strMsg As String, strInitialValue As String) As String
	' Define the javaobject
	Dim jo As JavaObject
	' Initialize using the Swing Library class JOptionPane
	jo.InitializeStatic("javax.swing.JOptionPane")
	Dim strInput As String = jo.RunMethod("showInputDialog", Array As Object(strMsg, strInitialValue))
	If strInput = "null" Then strInput = ""
	Return strInput
	' Log("showInputDialog: " & strInput)
End Sub

' Returns Input as text
Public Sub showInputDialog3(strMsg As String, strTitle As String, nType As Int) As String
	' Define the javaobject
	Dim jo As JavaObject
	' Initialize using the Swing Library class JOptionPane
	jo.InitializeStatic("javax.swing.JOptionPane")
	Dim strInput As String = jo.RunMethod("showInputDialog", Array As Object(Null, strMsg, strTitle, nType))
	If strInput = "null" Then strInput = ""
	Return strInput
	' Log("showInputDialog: " & strInput)
End Sub

' Returns Input as text
Public Sub showInputDialog4(strMsg As String, strTitle As String, nType As Int, lstOptions As List) As String
	' Convert the list into an array of objects
	Dim objOptions(lstOptions.Size) As Object
	For i = 0 To lstOptions.Size - 1
 		objOptions(i) = lstOptions.Get(i)
	Next	
	' Define the javaobject
	Dim jo As JavaObject
	' Initialize using the Swing Library class JOptionPane
	jo.InitializeStatic("javax.swing.JOptionPane")
	Dim strInput As String = jo.RunMethod("showInputDialog", Array As Object(Null, strMsg, strTitle, nType, Null, objOptions, Null))
	If strInput = "null" Then strInput = ""
	Return strInput
	' Log("showInputDialog: " & strInput)
End Sub

' Show About Message
' Parameter Message as String
Public Sub showAbout(strMsg As String)
	showMessage2(strMsg, "About", MSGTYPE_INFORMATION)	
End Sub

